@@ -46,6 +46,26 @@ namespace GAGGUI
 		archPtr=NULL;
 	}
 	
+	Selector::Selector(int x, int y, Uint32 hAlign, Uint32 vAlign, unsigned width, const std::string &tooltip, const std::string &tooltipFont, unsigned defaultValue, unsigned maxValue, unsigned step, const char *sprite, Sint32 id)
+		: RectangularWidget(tooltip, tooltipFont)
+	{
+		this->x=x;
+		this->y=y;
+		this->maxValue=maxValue;
+		this->step=step;
+		this->w=width;
+		this->h=10;
+		this->hAlignFlag=hAlign;
+		this->vAlignFlag=vAlign;
+		this->value=defaultValue;
+		this->dragging = false;
+	
+		if (sprite)
+			this->sprite=sprite;
+		this->id=id;
+		archPtr=NULL;
+	}
+	
 	void Selector::clipValue(int v)
 	{
 		if (v>=static_cast<int>(maxValue))
@@ -58,43 +78,46 @@ namespace GAGGUI
 		value = step * ((value + step/2) / step);
 	}
 	
-	void Selector::onSDLEvent(SDL_Event *event)
+	void Selector::onSDLMouseButtonDown(SDL_Event *event)
 	{
+		assert(event->type == SDL_MOUSEBUTTONDOWN);
 		int x, y, w, h;
 		getScreenPos(&x, &y, &w, &h);
-	
-		if (event->type==SDL_MOUSEBUTTONDOWN)
+		if (isPtInRect(event->button.x, event->button.y, x, y, w, h) &&
+			(event->button.button == SDL_BUTTON_LEFT))
 		{
-			if (isPtInRect(event->button.x, event->button.y, x, y, w, h) &&
-				(event->button.button == SDL_BUTTON_LEFT))
-			{
-				dragging = true;
-				int dx=event->button.x-x-3;
-				int v=dx*static_cast<int>(maxValue)/(w-4);
-				clipValue(v);
-				parent->onAction(this, VALUE_CHANGED, value, 0);
-			}
+			dragging = true;
+			int dx=event->button.x-x-3;
+			int v=dx*static_cast<int>(maxValue)/(w-4);
+			clipValue(v);
+			parent->onAction(this, VALUE_CHANGED, value, 0);
 		}
-		else if (event->type==SDL_MOUSEMOTION)
+	}
+		
+	void Selector::onSDLMouseMotion(SDL_Event *event)
+	{
+		assert(event->type == SDL_MOUSEMOTION);
+		int x, y, w, h;
+		getScreenPos(&x, &y, &w, &h);
+		if (dragging)
 		{
-			if (dragging)
-			{
-				int dx=event->button.x-x-3;
-				int v=dx*static_cast<int>(maxValue)/(w-4);
-				clipValue(v);
-				parent->onAction(this, VALUE_CHANGED, value, 0);
-			}
-		}
-		else if (event->type==SDL_MOUSEBUTTONUP)
-		{
-			if (event->button.button == SDL_BUTTON_LEFT)
-			{
-				dragging = false;
-			}
+			int dx=event->button.x-x-3;
+			int v=dx*static_cast<int>(maxValue)/(w-4);
+			clipValue(v);
+			parent->onAction(this, VALUE_CHANGED, value, 0);
 		}
 	}
 	
-	void Selector::init(void)
+	void Selector::onSDLMouseButtonUp(SDL_Event *event)
+	{
+		assert(event->type == SDL_MOUSEBUTTONUP);
+		if (event->button.button == SDL_BUTTON_LEFT)
+		{
+			dragging = false;
+		}
+	}
+	
+	void Selector::internalInit(void)
 	{
 		if (id>=0)
 		{
