@@ -26,7 +26,7 @@ using namespace GAGCore;
 
 namespace GAGGUI
 {
-	TextInput::TextInput(int x, int y, int w, int h, Uint32 hAlign, Uint32 vAlign, const char *font, const char *text, bool activated, size_t maxLength, bool password)
+	void TextInput::constructor(int x, int y, int w, int h, Uint32 hAlign, Uint32 vAlign, const char *font, const char *text, bool activated, size_t maxLength, bool password)
 	{
 		this->x=x;
 		this->y=y;
@@ -52,49 +52,49 @@ namespace GAGGUI
 	{
 	}
 	
-	void TextInput::setText(const char *newText)
+	void TextInput::setText(const std::string &newText)
 	{
-		this->text=newText;
-		cursPos=0;
-		textDep=0;
-		cursorScreenPos=0;
+		this->text = newText;
+		cursPos = 0;
+		textDep = 0;
+		cursorScreenPos = 0;
 		recomputeTextInfos();
 		parent->onAction(this, TEXT_SET, 0, 0);
 	}
 	
-	void TextInput::onSDLEvent(SDL_Event *event)
+	void TextInput::onSDLMouseButtonDown(SDL_Event *event)
 	{
+		assert(event->type == SDL_MOUSEBUTTONDOWN);
 		int x, y, w, h;
 		getScreenPos(&x, &y, &w, &h);
 		
-		HighlightableWidget::onSDLEvent(event);
-	
-		if (event->type==SDL_MOUSEBUTTONDOWN)
+		if (isPtInRect(event->button.x, event->button.y, x, y, w, h))
 		{
-			if (isPtInRect(event->button.x, event->button.y, x, y, w, h))
+			if (activated)
 			{
-				if (activated)
-				{
-					// we move cursor:
-					int dx=event->button.x-x-1;
-	
-					cursPos = text.length();
-					while((cursPos>0) && (fontPtr->getStringWidth(text.c_str()+textDep, cursPos-textDep)>dx))
-						--cursPos;
-	
-					recomputeTextInfos();
-					parent->onAction(this, TEXT_CURSOR_MOVED, 0, 0);
-				}
-				else
-				{
-					activated=true;
-					recomputeTextInfos();
-					parent->onAction(this, TEXT_ACTIVATED, 0, 0);
-				}
+				// we move cursor:
+				int dx=event->button.x-x-1;
+
+				cursPos = text.length();
+				while((cursPos>0) && (fontPtr->getStringWidth(text.c_str()+textDep, cursPos-textDep)>dx))
+					--cursPos;
+
+				recomputeTextInfos();
+				parent->onAction(this, TEXT_CURSOR_MOVED, 0, 0);
+			}
+			else
+			{
+				activated=true;
+				recomputeTextInfos();
+				parent->onAction(this, TEXT_ACTIVATED, 0, 0);
 			}
 		}
+	}
 	
-		if (activated && event->type==SDL_KEYDOWN)
+	void TextInput::onSDLKeyDown(SDL_Event *event)
+	{
+		assert(event->type == SDL_KEYDOWN);
+		if (activated)
 		{
 			SDLKey sym=event->key.keysym.sym;
 			SDLMod mod=event->key.keysym.mod;
@@ -254,7 +254,7 @@ namespace GAGGUI
 		}
 	}
 	
-	void TextInput::init(void)
+	void TextInput::internalInit(void)
 	{
 		fontPtr = Toolkit::getFont(font.c_str());
 		assert(fontPtr);
@@ -341,5 +341,49 @@ namespace GAGGUI
 			}
 		}
 	}
+	
+	/// adds word for autocompletion via <tab>
+	void TextInput::addAutoCompletableWord(const std::string &word)
+	{
+		autocompletableWord.push_back(word);
+	};
+	
+	/// removes word from autocompletion via <tab>
+	void TextInput::removeAutoCompletableWord(const std::string &word)
+	{
+		std::vector<std::string>::iterator it;
+		for (it = autocompletableWord.begin(); it != autocompletableWord.end(); ++it)
+		{
+			if (*it==word)
+				autocompletableWord.erase(it);
+		}
+	}
+	
+	/// returns the count of matching words for autocompletion for word and stores them to wordlist
+	bool TextInput::getAutoCompleteSuggestion(const std::string & word, std::vector<std::string> & wordlist)
+	{
+		int count = 0;
+		std::vector<std::string>::iterator it;
+		for (it = autocompletableWord.begin(); it != autocompletableWord.end(); ++it)
+		{
+			if(*it==word)
+			{
+				count++;
+				wordlist.push_back(*it);
+			}
+		}
+		if (count>0)
+			return true;
+		return false;
+	};
+	
+	/// returns the n-th suggestion
+	std::string TextInput::getAutoComplete(const std::string & word, int n)
+	{
+		std::vector<std::string> wordlist;
+		if (getAutoCompleteSuggestion(word, wordlist)>0)
+			return wordlist.at(n);
+		return std::string("");
+	}
 }
 
