@@ -27,6 +27,7 @@
 #include <Toolkit.h>
 #include <Stream.h>
 #include <BinaryStream.h>
+#include <FormatableString.h>
 
 #include "CustomGameScreen.h"
 #include "EndGameScreen.h"
@@ -42,6 +43,7 @@
 #include "YOGScreen.h"
 #include "SoundMixer.h"
 #include "CampaignScreen.h"
+
 #include <iostream>
 
 
@@ -58,26 +60,42 @@ Engine::Engine()
 Engine::~Engine()
 {
 	fprintf(logFile, "\n");
-	if (cpuSumCountStats)
+	if (globalContainer->runNoX)
 	{
-		double averageCupUsage = (double)cpuSumStats / (double)cpuSumCountStats;
-		fprintf(logFile, "averageCpuUsage = %d%%\n", (int)((double)2.5 * averageCupUsage));
+		Sint32 noxTicks = noxEndTick - noxStartTick;
+		double speed = (double)1000 * (double)cpuSumCountStats / (double)noxTicks;
+		fprintf(logFile, "nox::cpuSumCountStats = %d\n", cpuSumCountStats);
+		fprintf(logFile, "nox::noxTicks = %d\n", noxTicks);
+		fprintf(logFile, "nox::speed = %f [steps/s]\n", speed);
+		
+		printf("nox::cpuSumCountStats = %d\n", cpuSumCountStats);
+		printf("nox::noxTicks = %d\n", noxTicks);
+		printf("nox::speed = %f [steps/s]\n", speed);
 	}
-	fprintf(logFile, "cpu usage stats:\n");
-	for (int i=0; i<=40; i++)
-		fprintf(logFile, "%3d.%1d %% = %d\n", 100-(i*5)/2, (i&1)*5, cpuStats[i]);
-	int sum=0;
-	for (int i=0; i<=40; i++)
-		sum+=cpuStats[i];
-	fprintf(logFile, "cpu usage graph:\n");
-	for (int i=0; i<=40; i++)
+	else
 	{
-		fprintf(logFile, "%3d.%1d %% | ", 100-(i*5)/2, (i&1)*5);
-		double ratio=100.*(double)cpuStats[i]/(double)sum;
-		int jmax=(int)(ratio+0.5);
-		for (int j=0; j<jmax; j++)
-			fprintf(logFile, "*");
-		fprintf(logFile, "\n");
+		if (cpuSumCountStats)
+		{
+			fprintf(logFile, "cpuSumCountStats = %d\n", cpuSumCountStats);
+			double averageCupUsage = (double)cpuSumStats / (double)cpuSumCountStats;
+			fprintf(logFile, "averageCpuUsage = %lf%%\n", (double)2.5 * averageCupUsage);
+		}
+		fprintf(logFile, "cpu usage stats:\n");
+		for (int i=0; i<=40; i++)
+			fprintf(logFile, "%3d.%1d %% = %d\n", 100-(i*5)/2, (i&1)*5, cpuStats[i]);
+		int sum=0;
+		for (int i=0; i<=40; i++)
+			sum+=cpuStats[i];
+		fprintf(logFile, "cpu usage graph:\n");
+		for (int i=0; i<=40; i++)
+		{
+			fprintf(logFile, "%3d.%1d %% | ", 100-(i*5)/2, (i&1)*5);
+			double ratio=100.*(double)cpuStats[i]/(double)sum;
+			int jmax=(int)(ratio+0.5);
+			for (int j=0; j<jmax; j++)
+				fprintf(logFile, "*");
+			fprintf(logFile, "\n");
+		}
 	}
 
 	if (net)
@@ -183,26 +201,26 @@ int Engine::initCustom(void)
 	if (nbTeam==0)
 		return EE_CANCEL;
 
-	char name[BasePlayer::MAX_NAME_LENGTH];
 	int i;
 	int nbPlayer=0;
 
-	for (i=0; i<16; i++)
+	for (i=0; i<NumberOfPlayerSelectors; i++)
 	{
 		if (customGameScreen.isAIactive(i))
 		{
 			int teamColor=customGameScreen.getSelectedColor(i);
 			if (i==0)
 			{
-				gui.game.players[nbPlayer]=new Player(0, globalContainer->getUsername(), gui.game.teams[teamColor], BasePlayer::P_LOCAL);
+				gui.game.players[nbPlayer]=new Player(0, globalContainer->getUsername().c_str(), gui.game.teams[teamColor], BasePlayer::P_LOCAL);
 				gui.localPlayer=nbPlayer;
 				gui.localTeamNo=teamColor;
 			}
 			else
 			{
 				AI::ImplementitionID iid=customGameScreen.getAiImplementation(i);
-				snprintf(name, BasePlayer::MAX_NAME_LENGTH, "%s %d", Toolkit::getStringTable()->getString("[AI]", iid), nbPlayer-1);
-				gui.game.players[nbPlayer]=new Player(i, name, gui.game.teams[teamColor], Player::playerTypeFromImplementitionID(iid));
+				FormatableString name("%0 %1");
+				name.arg(Toolkit::getStringTable()->getString("[AI]", iid)).arg(nbPlayer-1);
+				gui.game.players[nbPlayer]=new Player(i, name.c_str(), gui.game.teams[teamColor], Player::playerTypeFromImplementitionID(iid));
 			}
 			gui.game.teams[teamColor]->numberOfPlayer++;
 			gui.game.teams[teamColor]->playersMask|=(1<<nbPlayer);
@@ -371,36 +389,46 @@ int Engine::run(void)
 	{
 		globalContainer->mix->setNextTrack(2, true);
 	}
+	if (globalContainer->runNoX)
+	{
+		printf("nox::game started\n");
+		noxStartTick = SDL_GetTicks();
+	}
 	
 	while (doRunOnceAgain)
 	{
+		const int speed=40;
 		Uint32 startTick, endTick;
-		bool networkReadyToExecute=true;
-		Sint32 ticksSpentInComputation=40;
-		Sint32 computationAvailableTicks=0;
-		Sint32 ticksToDelayInside=0;
-		Sint32 missedTicksToWait=0;
+		bool networkReadyToExecute = true;
+		Sint32 ticksSpentInComputation = speed;
+		Sint32 computationAvailableTicks = 0;
+		Sint32 ticksToDelayInside = 0;
+		Sint32 missedTicksToWait = 0;
 		
-		startTick=SDL_GetTicks();
+		startTick = SDL_GetTicks();
 		while (gui.isRunning)
 		{
+
 			// We always allow the user to use the gui:
 			if (globalContainer->runNoX)
 			{
 				if (!gui.getLocalTeam()->isAlive)
 				{
 					printf("nox::gui.localTeam is dead\n");
-					gui.isRunning=false;
+					gui.isRunning = false;
+					noxEndTick = SDL_GetTicks();
 				}
 				else if (gui.getLocalTeam()->hasWon)
 				{
 					printf("nox::gui.localTeam has won\n");
-					gui.isRunning=false;
+					gui.isRunning = false;
+					noxEndTick = SDL_GetTicks();
 				}
 				else if (gui.game.totalPrestigeReached)
 				{
 					printf("nox::gui.game.totalPrestigeReached\n");
-					gui.isRunning=false;
+					gui.isRunning = false;
+					noxEndTick = SDL_GetTicks();
 				}
 			}
 			else
@@ -457,7 +485,18 @@ int Engine::run(void)
 					gui.game.syncStep(gui.localTeamNo);
 			}
 
-			if (!globalContainer->runNoX)
+			if (globalContainer->runNoX)
+			{
+				if (cpuSumCountStats < (unsigned)-1)
+					cpuSumCountStats++;
+				if ((int)cpuSumCountStats == globalContainer->runNoXCountSteps)
+				{
+					gui.isRunning = false;
+					noxEndTick = SDL_GetTicks();
+					printf("nox::gui.game.checkSum() = %08x\n", gui.game.checkSum());
+				}
+			}
+			else
 			{
 				// we draw
 				gui.drawAll(gui.localTeamNo);
@@ -467,7 +506,7 @@ int Engine::run(void)
 				endTick=SDL_GetTicks();
 				Sint32 spentTicks=endTick-startTick;
 				ticksSpentInComputation=spentTicks-ticksDelayedInside;
-				computationAvailableTicks=40-ticksSpentInComputation;
+				computationAvailableTicks=speed-ticksSpentInComputation;
 				Sint32 ticksToWait=computationAvailableTicks+ticksToDelayInside+missedTicksToWait;
 				if (ticksToWait>0)
 				{
@@ -486,12 +525,15 @@ int Engine::run(void)
 				if (networkReadyToExecute && !gui.gamePaused)
 				{
 					Sint32 i = computationAvailableTicks;
-					cpuSumStats += 40 - computationAvailableTicks;
-					cpuSumCountStats++;
+					if (cpuSumCountStats < (unsigned)-1)
+					{
+						cpuSumStats += speed - computationAvailableTicks;
+						cpuSumCountStats++;
+					}
 					if (i<0)
 						i=0;
-					else if (i>=40)
-						i=40;
+					else if (i>=speed)
+						i=speed;
 					cpuStats[i]++;
 				}
 			}
@@ -502,7 +544,8 @@ int Engine::run(void)
 		
 		if (gui.exitGlobCompletely)
 			return -1; // There is no bypass for the "close window button"
-		
+
+	
 		doRunOnceAgain=false;
 		
 		if (gui.toLoadGameFileName[0])
