@@ -34,6 +34,7 @@
 #include "IntBuildingType.h"
 #include "Race.h"
 #include "Glob2Screen.h"
+#include "UnitsSkins.h"
 
 // version related stuff
 #ifdef HAVE_CONFIG_H
@@ -65,7 +66,6 @@ GlobalContainer::GlobalContainer(void)
 	settings.load();
 	userName = settings.username.c_str();
 	runNoX = false;
-	runNoXGameName[0] = 0;
 	
 	hostServer = false;
 	hostServerMapName[0] = 0;
@@ -79,10 +79,13 @@ GlobalContainer::GlobalContainer(void)
 	terrainBlack = NULL;
 	ressources = NULL;
 	units = NULL;
+	unitsSkins = NULL;
 
 	menuFont = NULL;
 	standardFont = NULL;
 	littleFont = NULL;
+	
+	voiceRecorder = NULL;
 
 	assert((int)USERNAME_MAX_LENGTH==(int)BasePlayer::MAX_NAME_LENGTH);
 }
@@ -92,12 +95,16 @@ GlobalContainer::~GlobalContainer(void)
 	// unlink GUI style
 	Style::style = &defaultStyle;
 	
+	// release unit skins
+	if (unitsSkins)
+		delete unitsSkins;
+	
 	// close sound
 	if (mix)
 		delete mix;
-		
-	if (rec)
-		delete rec;
+	
+	if (voiceRecorder)
+		delete voiceRecorder;
 	
 	// release ressources
 	Toolkit::close();
@@ -106,20 +113,20 @@ GlobalContainer::~GlobalContainer(void)
 	delete logFileManager;
 }
 
-void GlobalContainer::setUserName(const char *name)
+void GlobalContainer::setUserName(const std::string &name)
 {
-	settings.username.assign(name, USERNAME_MAX_LENGTH);
-	userName = settings.username.c_str();
+	settings.username.assign(name, 0, USERNAME_MAX_LENGTH);
+	userName = settings.username;
 }
 
-void GlobalContainer::pushUserName(const char *name)
+void GlobalContainer::pushUserName(const std::string &name)
 {
 	userName = name;
 }
 
 void GlobalContainer::popUserName()
 {
-	userName = settings.username.c_str();
+	userName = settings.username;
 }
 
 void GlobalContainer::parseArgs(int argc, char *argv[])
@@ -128,16 +135,23 @@ void GlobalContainer::parseArgs(int argc, char *argv[])
 	{
 		if (strcmp(argv[i], "-nox")==0 || strcmp(argv[i], "--nox")==0)
 		{
-			if (i+1<argc)
+			bool good = true;
+			if (i + 3 < argc)
 			{
-				strncpy(runNoXGameName, argv[i+1], 32);
+				runNoXGameName = argv[i + 1];
 				runNoX = true;
-				i++;
+				good &= (sscanf(argv[i + 2], "%d", &runNoXCountSteps) == 1);
+				good &= (sscanf(argv[i + 3], "%d", &runNoXCountRuns) == 1);
+				i += 3;
 			}
 			else
+				good = false;
+			if (!good)
 			{
 				printf("usage:\n");
-				printf("--nox <game file name>\n\n");
+				printf("--nox <game file name> <number of steps> <number of runs>\n");
+				printf("zero steps will make the game run until the end.\n");
+				printf("\n");
 				exit(0);
 			}
 			continue;
@@ -413,7 +427,7 @@ void GlobalContainer::load(void)
 		mix->setNextTrack(1);
 		
 		// create voice recorder
-		rec = new VoiceRecorder();
+		voiceRecorder = new VoiceRecorder();
 		
 		updateLoadProgressBar(10);
 	}
@@ -464,6 +478,7 @@ void GlobalContainer::load(void)
 		updateLoadProgressBar(70);
 		// load units
 		units = Toolkit::getSprite("data/gfx/unit");
+		unitsSkins = new UnitsSkins();
 
 		updateLoadProgressBar(90);
 		// load graphics for gui
