@@ -40,6 +40,7 @@ using namespace GAGCore;
 class SoundMixer;
 class VoiceRecorder;
 class LogFileManager;
+class UnitsSkins;
 
 class GlobalContainer
 {
@@ -52,7 +53,7 @@ private:
 	void updateLoadProgressBar(int value);
 	void destroyProgressBar(void);
 
-	const char *userName;
+	std::string userName;
 	
 public:
 	GlobalContainer(void);
@@ -61,10 +62,10 @@ public:
 	void parseArgs(int argc, char *argv[]);
 	void load(void);
 
-	void pushUserName(const char *name);
+	void pushUserName(const std::string &name);
 	void popUserName();
-	void setUserName(const char *name);
-	const char *getUsername(void) { return userName; }
+	void setUserName(const std::string &name);
+	const std::string &getUsername(void) { return userName; }
 	const char *getComputerHostName(void);
 
 public:
@@ -73,7 +74,8 @@ public:
 
 	GraphicContext *gfx;
 	SoundMixer *mix;
-	VoiceRecorder *rec;
+	VoiceRecorder *voiceRecorder;
+	
 	Sprite *terrain;
 	Sprite *terrainWater;
 	Sprite *terrainCloud;
@@ -90,6 +92,8 @@ public:
 	Sprite *brush;
 	Sprite *magiceffect;
 	
+	UnitsSkins *unitsSkins;
+	
 	Font *menuFont;
 	Font *standardFont;
 	Font *littleFont;
@@ -102,7 +106,9 @@ public:
 	RessourcesTypes ressourcesTypes;
 
 	bool runNoX;
-	char runNoXGameName[32];
+	std::string runNoXGameName;
+	int runNoXCountRuns; //!< The number of runs you want to repeat the no X run
+	int runNoXCountSteps; //!< The number of steps you want the no X game to run
 	
 	bool hostServer;
 	char hostServerMapName[32];
