@@ -78,6 +78,7 @@ public:
 	virtual ~Map(void);
 	//! Reset map and free arrays
 	void clear();
+	void logAtClear();
 
 	//! Reset map size to width = 2^wDec and height=2^hDec, and fill background with terrainType
 	void setSize(int wDec, int hDec, TerrainType terrainType=WATER);
@@ -196,23 +197,46 @@ public:
 	}
 	
 	//! Return true if the position (x,y) is a forbidden area set by the user
+	// or rather, by the team computeLocalForbidden was last called for
 	bool isForbiddenLocal(int x, int y)
 	{
 		return localForbiddenMap.get(((y&hMask)<<wDec)+(x&wMask));
 	}
 	
+	//! Returns true if the position(x, y) is a forbideen area for the given team
+	bool isForbidden(int x, int y, Uint32 teamMask)
+	{
+		return cases[((y&hMask)<<wDec)+(x&wMask)].forbidden&teamMask;
+	}
+
 	//! Return true if the position (x,y) is a guard area set by the user
+	// or rather, by the team computeLocalGuardArea was last called for
 	bool isGuardAreaLocal(int x, int y)
 	{
 		return localGuardAreaMap.get(((y&hMask)<<wDec)+(x&wMask));
 	}
 	
+	//! Returns true if the position(x, y) is a guard area for the given team
+	bool isGuardArea(int x, int y, Uint32 teamMask)
+	{
+		return cases[((y&hMask)<<wDec)+(x&wMask)].guardArea&teamMask;
+	}
+
 	//! Return true if the position (x,y) is a clear area set by the user
+	// or rather, by the team computeLocalClearArea was last called for
 	bool isClearAreaLocal(int x, int y)
 	{
 		return localClearAreaMap.get(((y&hMask)<<wDec)+(x&wMask));
 	}
+
+	//! Returns true if the position(x, y) is a clear area for the given team
+	bool isClearArea(int x, int y, Uint32 teamMask)
+	{
+		return cases[((y&hMask)<<wDec)+(x&wMask)].clearArea&teamMask;
+	}
 	
+	// note - these are only meant to be called for the LOCAL team
+	// (the one whose stuff is displayed on the screen, etc)
 	//! Compute localForbiddenMap from cases array
 	void computeLocalForbidden(int localTeamNo);
 	//! Compute localGuardAreaMap from cases array
@@ -421,6 +445,16 @@ public:
 	//! Transform coordinate from building (px,py) to screen (mx,my)
 	void buildingPosToCursor(int px, int py, int buildingWidth, int buildingHeight, int *mx, int *my, int viewportX, int viewportY);
 	
+	enum GradientType
+	{
+		GT_UNDEFINED = 0,
+		GT_RESOURCE = 1,
+		GT_BUILDING = 2,
+		GT_FORBIDDEN = 3,
+		GT_GUARD_AREA = 4,
+		GT_SIZE = 5
+	};
+	
 	bool ressourceAvailable(int teamNumber, int ressourceType, bool canSwim, int x, int y);
 	bool ressourceAvailable(int teamNumber, int ressourceType, bool canSwim, int x, int y, int *dist);
 	bool ressourceAvailable(int teamNumber, int ressourceType, bool canSwim, int x, int y, Sint32 *targetX, Sint32 *targetY, int *dist);
@@ -437,7 +471,13 @@ public:
 	
 	void updateGlobalGradientSlow(Uint8 *gradient);
 	template<typename Tint> void updateGlobalGradientSlow(Uint8 *gradient);
-	template<typename Tint> void updateGlobalGradient(Uint8 *gradient, Tint *listedAddr, size_t listCountWrite);
+	
+	template<typename Tint> void updateGlobalGradientVersionSimple(
+		Uint8 *gradient, Tint *listedAddr, size_t listCountWrite, GradientType gradientType);
+	template<typename Tint> void updateGlobalGradientVersionSimon(Uint8 *gradient, Tint *listedAddr, size_t listCountWrite);
+	template<typename Tint> void updateGlobalGradientVersionKai(Uint8 *gradient, Tint *listedAddr, size_t listCountWrite);
+	template<typename Tint> void updateGlobalGradient(
+		Uint8 *gradient, Tint *listedAddr, size_t listCountWrite, GradientType gradientType, bool canSwim);
 	//void updateGlobalGradientSmall(Uint8 *gradient);
 	//void updateGlobalGradientBig(Uint8 *gradient);
 	//void updateGlobalGradient(Uint8 *gradient);
@@ -555,7 +595,16 @@ protected:
 	int pathfindForbiddenCount;
 	int pathfindForbiddenCountSuccess;
 	int pathfindForbiddenCountFailure;
+	
+	//#define check_disorderable_gradient_error_probability
+	#ifdef check_disorderable_gradient_error_probability
+	// stats to check the probability of an error in the updateGlobalGradientVersionDisorderable gradient computation
+	int *listCountSizeStats[GT_SIZE];
+	int listCountSizeStatsOver[GT_SIZE];
+	#endif
 
+public:
+	Game *game;
 public:
 	Case *cases;
 	Sint32 w, h;
@@ -612,7 +661,6 @@ protected:
 	Sint32 wSector, hSector;
 	int sizeSector;
 	
-	Game *game;
 
 public:
 	Uint32 checkSum(bool heavy);
