@@ -22,6 +22,7 @@
 
 #include "Header.h"
 #include <string>
+#include <map>
 
 class Settings
 {
@@ -35,7 +36,13 @@ public:
 	Uint32 defaultLanguage;
 	Uint32 musicVolume;
 	int mute;
-
+	bool rememberUnit;
+	int warflagUnit;
+	int clearflagUnit;
+	int exploreflagUnit;
+	std::map<std::string, std::string> keyboard_shortcuts;
+	std::map<std::string, std::string> editor_keyboard_shortcuts;
+	void restoreDefaultShortcuts();
 public:
 	void load(const char *filename="preferences.txt");
 	void save(const char *filename="preferences.txt");
