@@ -21,17 +21,20 @@
 #define __UNIT_H
 
 #include <vector>
+#include <string>
 #include <assert.h>
 #include <string.h>
 
 #include <GAGSys.h>
 #include "UnitConsts.h"
+#include "Ressource.h"
 
 #define LEVEL_UP_ANIMATION_FRAME_COUNT 20
 #define MAGIC_ACTION_ANIMATION_FRAME_COUNT 8
 
 class Team;
 class Race;
+class UnitSkin;
 class Building;
 
 namespace GAGCore
@@ -61,19 +64,19 @@ public:
 	static int directionFromDxDy(int dx, int dy);
 	inline static void dxdyfromDirection(int direction, int *dx, int *dy)
 	{
-	const int tab[9][2]={	{ -1, -1},
-							{ 0, -1},
-							{ 1, -1},
-							{ 1, 0},
-							{ 1, 1},
-							{ 0, 1},
-							{ -1, 1},
-							{ -1, 0},
-							{ 0, 0} };
-	assert(direction>=0);
-	assert(direction<=8);
-	*dx=tab[direction][0];
-	*dy=tab[direction][1];
+		const int tab[9][2]={	{ -1, -1},
+								{ 0, -1},
+								{ 1, -1},
+								{ 1, 0},
+								{ 1, 1},
+								{ 0, 1},
+								{ -1, 1},
+								{ -1, 0},
+								{ 0, 0} };
+		assert(direction>=0);
+		assert(direction<=8);
+		*dx=tab[direction][0];
+		*dy=tab[direction][1];
 	}
 	
 	static Sint32 GIDtoID(Uint16 gid);
@@ -90,6 +93,8 @@ public:
 	int getNextLevelThreshold(void) const;
 	void incrementExperience(int increment);
 	
+	void skinPointerFromName(void);
+	
 public:
 
 	enum Medical
@@ -173,12 +178,17 @@ protected:
 	void gotoGroundTarget(); //This will set (dx,dy) given targetX/Y. ground asserted.
 	void escapeGroundTarget(); //This will set (dx,dy) opposed to the given targetX/Y, without the care of forbidden flags ground asserted.
 	void simplifyDirection(int ldx, int ldy, int *cdx, int *cdy);
+	void defaultSkinNameFromType(void);
+
+	bool locationIsInEnemyGuardTowerRange(int x, int y)const;
 	
 public:
 	
 	// unit specification
 	Sint32 typeNum; // Uint8, WORKER, EXPLORER, WARRIOR
 	Race *race;
+	UnitSkin *skin;
+	std::string skinName;
 	
 	// identity
 	Uint16 gid; // for reservation see GIDtoID() and GIDtoTeam().
@@ -210,6 +220,7 @@ public:
 
 	// hungry : maxfood = 100000
 	Sint32 hungry; // (Uint16)
+	Sint32 hungryness;
 	Sint32 trigHungry; // (Uint16)
 	Sint32 trigHungryCarying;
 	Uint32 fruitMask;
@@ -234,7 +245,18 @@ public:
 	// gui
 	int levelUpAnimation;
 	int magicActionAnimation;
+	
+public:
+	// optimisation cached values
+	int stepsLeftUntilHungry;
+	int minDistToResource[MAX_RESSOURCES];
+	bool allResourcesAreTooFar;
 
+public:
+	// computing optimisation cached values
+	int numberOfStepsLeftUntilHungry(void);
+	void computeMinDistToResources(void);
+	
 public:
 	void integrity();
 	Uint32 checkSum(std::vector<Uint32> *checkSumsVector);
